@@ -118,31 +118,34 @@ int main( int argc, char *argv[] )
     KCmdLineArgs::init( argc, argv, &aboutData );
     KCmdLineOptions options;
     options.add("profile <profile>", ki18n( "Profile to load" ));
+    options.add("s <session>", ki18n("Session to load" ));
     options.add("project <project>", ki18n( "Url to project to load" ));
     options.add("+files", ki18n( "Files to load" ));
     KCmdLineArgs::addCmdLineOptions( options );
     KCmdLineArgs* args = KCmdLineArgs::parsedArgs();
 
-#ifdef Q_WS_X11
-#if QT_VERSION >= 0x040502
-    //Text rendering on X11 is exceptionally slow, so force Qt
-    //raster graphics system (mostly) to make kate editor feel faster
-    QApplication::setGraphicsSystem("raster");
-#endif
-#endif
-
     KApplication app;
     KDevIDEExtension::init();
-    
-    KSplashScreen* splash = 0;
-    QString splashFile = KStandardDirs::locate( "appdata", "pics/kdevelop-splash.png" );
-    if( !splashFile.isEmpty() )
+
+    QString sessionName = args->getOption("s");
+    if(!sessionName.isEmpty())
+        setenv("KDEV_SESSION", sessionName.toLatin1(), 1);
+
+    if(!getenv("KDEV_SESSION"))
     {
-        QPixmap pm;
-        pm.load( splashFile );
-        splash = new KSplashScreen( pm );
-        splash->show();
-        QTimer::singleShot(0, splash, SLOT(deleteLater()));
+        ///Only show the splash-screen if no session has been given.
+        ///If a session has been given, that usually means that KDevelop has already been loaded,
+        ///and startup will be very fast. A splash-screen looks unaesthetical then.
+        KSplashScreen* splash = 0;
+        QString splashFile = KStandardDirs::locate( "appdata", "pics/kdevelop-splash.png" );
+        if( !splashFile.isEmpty() )
+        {
+            QPixmap pm;
+            pm.load( splashFile );
+            splash = new KSplashScreen( pm );
+            splash->show();
+            QTimer::singleShot(0, splash, SLOT(deleteLater()));
+        }
     }
 
     Core::initialize();
