@@ -64,8 +64,6 @@ DebugSession::DebugSession()
       m_sessionState(NotStartedState),
       justRestarted_(false),
       m_config(KGlobal::config(), "GDB Debugger"),
-      currentFrame_(0),
-      currentThread_(-1),
       commandQueue_(new CommandQueue),
       tty_(0),
       state_(s_dbgNotStarted|s_appNotStarted),
@@ -215,13 +213,6 @@ void DebugSession::_gdbStateChanged(DBGStateFlags oldState, DBGStateFlags newSta
         }
     }
 
-    // VP, 2009-9-11: temporary disabled because:
-    // - we don't have status bar at present
-    // - it's not clear how to display 'running/stopped' when
-    //   we have non-stop
-    // A better general solution would be to keep running/stopped
-    // state for each thread in the framestack model.
-#if 0
     if (changedState & s_appRunning) {
         if (newState & s_appRunning) {
             message = i18n("Application is running");
@@ -248,7 +239,6 @@ void DebugSession::_gdbStateChanged(DBGStateFlags oldState, DBGStateFlags newSta
             }
         }
     }
-#endif
 
     // And now? :-)
     kDebug(9012) << "Debugger state: " << newState << ": ";
@@ -289,6 +279,9 @@ void DebugSession::attachToProcess(int pid)
     setStateOff(s_appNotStarted|s_programExited);
     setStateOn(s_attached);
 
+    //set current state to running, after attaching we will get *stopped response
+    setStateOn(s_appRunning);
+
     if (stateIsOn(s_dbgNotStarted))
       startDebugger(0);
 
@@ -562,16 +555,6 @@ void DebugSession::addCommandBeforeRun(GDBCommand* cmd)
     queueCmd(cmd, QueueWhileInterrupted);
 }
 
-int  DebugSession::currentThread() const
-{
-    return currentThread_;
-}
-
-int DebugSession::currentFrame() const
-{
-    return currentFrame_;
-}
-
 // Fairly obvious that we'll add whatever command you give me to a queue
 // If you tell me to, I'll put it at the head of the queue so it'll run ASAP
 // Not quite so obvious though is that if we are going to run again. then any
@@ -598,7 +581,7 @@ void DebugSession::queueCmd(GDBCommand *cmd, QueuePosition queue_where)
                                  && cmd->type() != GDBMI::VarDelete);
 
     bool stackCommandWithContext = (cmd->type() >= GDBMI::StackInfoDepth
-                                    && cmd->type() <= GDBMI::StackListVariables);
+                                    && cmd->type() <= GDBMI::StackListLocals);
 
     if (varCommandWithContext || stackCommandWithContext)
     {
@@ -689,6 +672,7 @@ void DebugSession::slotProgramStopped(const GDBMI::ResultRecord& r)
 {
     /* By default, reload all state on program stop.  */
     state_reload_needed = true;
+    setStateOff(s_appRunning);
 
     QString reason;
     if (r.hasField("reason")) reason = r["reason"].literal();
@@ -809,11 +793,6 @@ void DebugSession::programNoApp(const QString& msg)
 
     destroyCmds();
 
-    // We're always at frame zero when the program stops
-    // and we must reset the active flag
-    currentThread_ = -1;
-    currentFrame_ = 0;
-
     // The application has existed, but it's possible that
     // some of application output is still in the pipe. We use
     // different pipes to communicate with gdb and to get application
@@ -866,6 +845,7 @@ void DebugSession::parseStreamRecord(const GDBMI::StreamRecord& s)
         QString line = s.message;
         if (line.startsWith("Program terminated")) {
             //when examining core file
+            setStateOff(s_appRunning);
             setStateOn(s_appNotStarted|s_programExited);
         } else if (line.startsWith("The program no longer exists")
             || line.startsWith("Program exited"))
@@ -875,27 +855,6 @@ void DebugSession::parseStreamRecord(const GDBMI::StreamRecord& s)
     }
 }
 
-void DebugSession::handleMiFrameSwitch(const GDBMI::ResultRecord& r)
-{
-    raiseEvent(thread_or_frame_changed);
-
-    const GDBMI::Value& frame = r["frame"];
-
-    QString file;
-    if (frame.hasField("fullname"))
-        file = frame["fullname"].literal();
-    else if (frame.hasField("file"))
-        file = frame["file"].literal();
-
-    int line = -1;
-    if (frame.hasField("line"))
-        line = frame["line"].literal().toInt();
-
-    emitShowStepInSource(file,
-                     line,
-                     frame["addr"].literal());
-}
-
 bool DebugSession::startDebugger(KDevelop::ILaunchConfiguration* cfg)
 {
     kDebug(9012) << "Starting debugger controller";
@@ -935,8 +894,6 @@ bool DebugSession::startDebugger(KDevelop::ILaunchConfiguration* cfg)
 
     connect(m_gdb, SIGNAL(streamRecord(const GDBMI::StreamRecord&)),
             this, SLOT(parseStreamRecord(const GDBMI::StreamRecord&)));
-    connect(m_gdb, SIGNAL(resultRecord(const GDBMI::ResultRecord&)),
-            this, SLOT(resultRecord(const GDBMI::ResultRecord&)));
 
     // Start gdb. Do this after connecting all signals so that initial
     // GDB output, and important events like "GDB died" are reported.
@@ -1234,23 +1191,6 @@ void DebugSession::jumpTo(const KUrl& url, int line)
 
 // **************************************************************************
 
-void DebugSession::selectFrame(int frameNo, int threadNo)
-{
-    // FIXME: this either should be removed completely, or
-    // trigger an error message.
-    if (stateIsOn(s_dbgNotStarted|s_shuttingDown))
-        return;
-
-    // Will emit the 'thread_or_frame_changed' event.
-    GDBCommand* stackInfoFrame = new GDBCommand(GDBMI::StackInfoFrame);
-    stackInfoFrame->setThread(threadNo);
-    stackInfoFrame->setFrame(frameNo);
-    stackInfoFrame->setHandler(this, &DebugSession::handleMiFrameSwitch);
-    queueCmd(stackInfoFrame);
-}
-
-// **************************************************************************
-
 // FIXME: connect to GDB's slot.
 void DebugSession::defaultErrorHandler(const GDBMI::ResultRecord& result)
 {
@@ -1286,23 +1226,6 @@ void DebugSession::defaultErrorHandler(const GDBMI::ResultRecord& result)
         raiseEvent(program_state_changed);
 }
 
-void DebugSession::resultRecord(const GDBMI::ResultRecord& result)
-{
-    GDBCommand* cmd = m_gdb->currentCommand();
-    switch (cmd->type()) {
-    case GDBMI::ThreadSelect:
-        if (result.hasField("new-thread-id"))
-            currentThread_ = result["new-thread-id"].toInt();
-        currentFrame_ = 0;
-        break;
-    case GDBMI::StackSelectFrame:
-        currentFrame_ = cmd->command().toInt();
-        break;
-    default:
-        break;
-    }
-}
-
 void DebugSession::gdbReady()
 {
     stateReloadInProgress_ = false;
@@ -1466,6 +1389,7 @@ void DebugSession::debugStateChange(DBGStateFlags oldState, DBGStateFlags newSta
                 STATE_CHECK(s_shuttingDown);
                 STATE_CHECK(s_explicitBreakInto);
                 STATE_CHECK(s_dbgBusy);
+                STATE_CHECK(s_appRunning);
 #undef STATE_CHECK
 
                 if (!found)
@@ -1480,6 +1404,7 @@ void DebugSession::debugStateChange(DBGStateFlags oldState, DBGStateFlags newSta
 
 void DebugSession::programRunning()
 {
+    setStateOn(s_appRunning);
     raiseEvent(program_running);
 }
 
