@@ -840,6 +840,7 @@ void GdbTest::testVariablesLocals()
     breakpoints()->addCodeBreakpoint(debugeeFileName, 22);
     QVERIFY(session->startProgram(&cfg));
     WAIT_FOR_STATE(session, DebugSession::PausedState);
+    QTest::qWait(1000);
 
     QCOMPARE(variableCollection()->rowCount(), 2);
     QModelIndex i = variableCollection()->index(1, 0);
@@ -848,6 +849,7 @@ void GdbTest::testVariablesLocals()
     COMPARE_DATA(variableCollection()->index(0, 0, i), "i");
     COMPARE_DATA(variableCollection()->index(0, 1, i), "0");
     session->run();
+    QTest::qWait(1000);
     WAIT_FOR_STATE(session, DebugSession::PausedState);
     COMPARE_DATA(variableCollection()->index(0, 0, i), "i");
     COMPARE_DATA(variableCollection()->index(0, 1, i), "1");
@@ -865,7 +867,7 @@ void GdbTest::testVariablesLocalsStruct()
     breakpoints()->addCodeBreakpoint(debugeeFileName, 38);
     QVERIFY(session->startProgram(&cfg));
     WAIT_FOR_STATE(session, DebugSession::PausedState);
-    QTest::qWait(300);
+    QTest::qWait(1000);
 
     QModelIndex i = variableCollection()->index(1, 0);
     QCOMPARE(variableCollection()->rowCount(i), 4);
@@ -884,6 +886,7 @@ void GdbTest::testVariablesLocalsStruct()
 
     session->stepInto();
     WAIT_FOR_STATE(session, DebugSession::PausedState);
+    QTest::qWait(1000);
     COMPARE_DATA(variableCollection()->index(1, 0, i), "ts");
     COMPARE_DATA(variableCollection()->index(1, 1, i), "{...}");
     COMPARE_DATA(variableCollection()->index(0, 1, ts), "1");
@@ -923,6 +926,7 @@ void GdbTest::testVariablesWatches()
 
     session->stepInto();
     WAIT_FOR_STATE(session, DebugSession::PausedState);
+    QTest::qWait(100);
     COMPARE_DATA(variableCollection()->index(0, 0, i), "ts");
     COMPARE_DATA(variableCollection()->index(0, 1, i), "{...}");
     COMPARE_DATA(variableCollection()->index(0, 1, ts), "1");
@@ -935,7 +939,7 @@ void GdbTest::testVariablesWatches()
 void GdbTest::testVariablesWatchesTwoSessions()
 {
     TestDebugSession *session = new TestDebugSession;
-    session->variableController()->setAutoUpdate(KDevelop::IVariableController::UpdateLocals);
+    session->variableController()->setAutoUpdate(KDevelop::IVariableController::UpdateWatches);
 
     TestLaunchConfiguration cfg;
 
@@ -963,7 +967,7 @@ void GdbTest::testVariablesWatchesTwoSessions()
 
     //start a second debug session
     session = new TestDebugSession;
-    session->variableController()->setAutoUpdate(KDevelop::IVariableController::UpdateLocals);
+    session->variableController()->setAutoUpdate(KDevelop::IVariableController::UpdateWatches);
     QVERIFY(session->startProgram(&cfg));
     WAIT_FOR_STATE(session, DebugSession::PausedState);
     QTest::qWait(300);
@@ -1026,6 +1030,83 @@ void GdbTest::testVariablesStartSecondSession()
     WAIT_FOR_STATE(session, DebugSession::EndedState);
 }
 
+void GdbTest::testVariablesSwitchFrame()
+{
+    TestDebugSession *session = new TestDebugSession;
+    TestLaunchConfiguration cfg;
+
+    session->variableController()->setAutoUpdate(KDevelop::IVariableController::UpdateLocals);
+    TestFrameStackModel *stackModel = session->frameStackModel();
+
+    breakpoints()->addCodeBreakpoint(debugeeFileName, 24);
+    QVERIFY(session->startProgram(&cfg));
+    WAIT_FOR_STATE(session, DebugSession::PausedState);
+    QTest::qWait(500);
+
+    QModelIndex i = variableCollection()->index(1, 0);
+    COMPARE_DATA(i, "Locals");
+    QCOMPARE(variableCollection()->rowCount(i), 1);
+    COMPARE_DATA(variableCollection()->index(0, 0, i), "i");
+    COMPARE_DATA(variableCollection()->index(0, 1, i), "1");
+
+    stackModel->setCurrentFrame(1);
+    QTest::qWait(200);
+
+    i = variableCollection()->index(1, 0);
+    QCOMPARE(variableCollection()->rowCount(i), 4);
+    COMPARE_DATA(variableCollection()->index(2, 0, i), "argc");
+    COMPARE_DATA(variableCollection()->index(2, 1, i), "1");
+    COMPARE_DATA(variableCollection()->index(3, 0, i), "argv");
+
+    breakpoints()->removeRow(0);
+    session->run();
+    WAIT_FOR_STATE(session, DebugSession::EndedState);
+}
+
+void GdbTest::testVariablesQuicklySwitchFrame()
+{
+    TestDebugSession *session = new TestDebugSession;
+    TestLaunchConfiguration cfg;
+
+    session->variableController()->setAutoUpdate(KDevelop::IVariableController::UpdateLocals);
+    TestFrameStackModel *stackModel = session->frameStackModel();
+
+    breakpoints()->addCodeBreakpoint(debugeeFileName, 24);
+    QVERIFY(session->startProgram(&cfg));
+    WAIT_FOR_STATE(session, DebugSession::PausedState);
+    QTest::qWait(500);
+
+    QModelIndex i = variableCollection()->index(1, 0);
+    COMPARE_DATA(i, "Locals");
+    QCOMPARE(variableCollection()->rowCount(i), 1);
+    COMPARE_DATA(variableCollection()->index(0, 0, i), "i");
+    COMPARE_DATA(variableCollection()->index(1, 0, i), "1");
+
+    stackModel->setCurrentFrame(1);
+    QTest::qWait(300);
+    stackModel->setCurrentFrame(0);
+    QTest::qWait(1);
+    stackModel->setCurrentFrame(1);
+    QTest::qWait(1);
+    stackModel->setCurrentFrame(0);
+    QTest::qWait(1);
+    stackModel->setCurrentFrame(1);
+    QTest::qWait(500);
+
+    i = variableCollection()->index(1, 0);
+    QCOMPARE(variableCollection()->rowCount(i), 4);
+    QStringList locs;
+    for (int j = 0; j < variableCollection()->rowCount(i); ++j) {
+        locs << variableCollection()->index(j, 0, i).data().toString();
+    }
+    QVERIFY(locs.contains("argc"));
+    QVERIFY(locs.contains("argv"));
+    QVERIFY(locs.contains("x"));
+
+    breakpoints()->removeRow(0);
+    session->run();
+    WAIT_FOR_STATE(session, DebugSession::EndedState);
+}
 
 void GdbTest::waitForState(GDBDebugger::DebugSession *session, DebugSession::DebuggerState state,
                             const char *file, int line)
