@@ -65,6 +65,8 @@ private Q_SLOTS:
     void testVariablesWatchesTwoSessions();
     void testVariablesStopDebugger();
     void testVariablesStartSecondSession();
+    void testVariablesSwitchFrame();
+    void testVariablesQuicklySwitchFrame();
 private:
     KDevelop::TestCore* m_core;
     void waitForState(GDBDebugger::DebugSession *session, KDevelop::IDebugSession::DebuggerState state, const char *file, int line);
