@@ -62,6 +62,9 @@
 #include <cpputils.h>
 #include <interfaces/ilanguage.h>
 
+///Created statically as this object must be a child of the main thread
+CppUtils::ReplaceCurrentAccess accessReplacer;
+
 QString lastLines(QString str, int count = 40) {
   QStringList lines = str.split("\n");
   if(lines.count() < count)
@@ -142,7 +145,7 @@ QString extractLastLine(const QString& str) {
 }
 
 bool isPrefixKeyword(QString str) {
-  return str == "new" || str == "return" || str == "else" || str == "throw" || str == "delete" || str == "emit" || str == "Q_EMIT";
+  return str == "new" || str == "return" || str == "else" || str == "throw" || str == "delete" || str == "emit" || str == "Q_EMIT" || str == "case";
 }
 
 int completionRecursionDepth = 0;
@@ -226,7 +229,6 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
 
   if(doConstructorCompletion())
     return;
-  ///@todo template-parameters
 
   ///First: find out what kind of completion we are dealing with
 
@@ -364,12 +366,12 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
   ///Handle constructions like "ClassType instance("
   if(!expressionPrefix.isEmpty() && (expressionPrefix.endsWith('>') || expressionPrefix[expressionPrefix.length()-1].isLetterOrNumber() || expressionPrefix[expressionPrefix.length()-1] == '_')) {
     int newExpressionStart = Utils::expressionAt(expressionPrefix, expressionPrefix.length());
-    if(newExpressionStart > 0) {
+    if(newExpressionStart >= 0) {
       QString newExpression = expressionPrefix.mid(newExpressionStart).trimmed();
       QString newExpressionPrefix = stripFinalWhitespace( expressionPrefix.left(newExpressionStart) );
       if(!isPrefixKeyword(newExpression)) {
         if(newExpressionPrefix.isEmpty() || newExpressionPrefix.endsWith(';') || newExpressionPrefix.endsWith('{') || newExpressionPrefix.endsWith('}')) {
-          kDebug(9007) << "skipping expression" << m_expression << "and setting new expression" << newExpression;
+          ifDebug( kDebug(9007) << "skipping expression" << m_expression << "and setting new expression" << newExpression; )
           m_expression = newExpression;
           expressionPrefix = newExpressionPrefix;
           m_isDeclarationTypePrefix = true;
@@ -381,7 +383,6 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
   ///Handle recursive contexts(Example: "ret = function1(param1, function2(" )
   if( (expressionPrefix.endsWith( '<' ) || expressionPrefix.endsWith('(') || expressionPrefix.endsWith(',') || expressionPrefix.endsWith(':')) 
       && getEndOperator(expressionPrefix).length() < 2 ) { //Do not try a function-call for example with "<<", as that may lead to a quadratic expansion together with the operator expansion
-    log( QString("Recursive function-call: Searching parent-context in \"%1\"").arg(expressionPrefix) );
     //Our expression is within a function-call. We need to find out the possible argument-types we need to match, and show an argument-hint.
 
     //Find out which argument-number this expression is, and compute the beginning of the parent function-call(parentContextLast)
@@ -391,9 +392,16 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
     skipFunctionArguments( expressionPrefix, otherArguments, parentContextEnd );
 
     QString parentContextText = expressionPrefix.left(parentContextEnd);
-
-    log( QString("This argument-number: %1 Building parent-context from \"%2\"").arg(otherArguments.size()).arg(parentContextText) );
-    m_parentContext = new CodeCompletionContext( m_duContext, parentContextText, QString(), m_position, depth+1, otherArguments );
+    
+    //Prevent useless endless recursion
+    if(depth == 0 || parentContextText != m_text)
+    {
+      log( QString("Recursive function-call: Searching parent-context in \"%1\"").arg(expressionPrefix) );
+      log( QString("This argument-number: %1 Building parent-context from \"%2\"").arg(otherArguments.size()).arg(parentContextText) );
+      m_parentContext = new CodeCompletionContext( m_duContext, parentContextText, QString(), m_position, depth+1, otherArguments );
+    }else{
+      ifDebug( kDebug() << "not following at depth" << depth << " because:" << parentContextText << "==" << m_text; )
+    }
   }
 
   ///Handle signal/slot access
@@ -469,8 +477,13 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
 
   ///Handle overridden binary operator-functions
   if( endsWithOperator(expressionPrefix) || expressionPrefix.endsWith("return") ) {
-    log( QString( "Recursive operator: creating parent-context with \"%1\"" ).arg(expressionPrefix) );
-    m_parentContext = new CodeCompletionContext( m_duContext, expressionPrefix, QString(), m_position, depth+1 );
+    if(depth == 0 || m_text != expressionPrefix) {
+      log( QString( "Recursive operator: creating parent-context with \"%1\"" ).arg(expressionPrefix) );
+      m_parentContext = new CodeCompletionContext( m_duContext, expressionPrefix, QString(), m_position, depth+1 );
+    }else{
+      ifDebug( kDebug() << "not following operator at depth" << depth << " because:" << expressionPrefix  << "==" << m_text; )
+    }
+    
   }
 
   ///Now care about m_expression. It may still contain keywords like "new "
@@ -490,6 +503,12 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
       m_memberAccessOperation = ReturnAccess;
     }
   }
+  if( removePrefixWord(expr, "case") )  {
+    if(!expr.isEmpty() || depth == 0) {
+      //Create a new context for the "case"
+      m_parentContext = new CodeCompletionContext( m_duContext, "case", QString(), m_position, depth+1 );
+    }
+  }
   if( removePrefixWord(expr, "delete") )  {
     QRegExp bracketRE("^\\s*\\[\\s*\\]");
     if (expr.contains(bracketRE))
@@ -510,11 +529,14 @@ CodeCompletionContext::CodeCompletionContext(KDevelop::DUContextPointer context,
     m_onlyShowTypes = true;
     m_pointerConversionsBeforeMatching = 1;
   }
+  
   ExpressionParser expressionParser/*(false, true)*/;
 
   ifDebug( kDebug(9007) << "expression: " << expr; )
 
   if( !expr.trimmed().isEmpty() && !m_expressionResult.isValid() ) {
+    LOCKDUCHAIN;
+
     if(!m_isDeclarationTypePrefix) {
       m_expressionResult = expressionParser.evaluateExpression( expr.toUtf8(), m_duContext );
     }else{
@@ -1049,6 +1071,9 @@ CodeCompletionContext* CodeCompletionContext::parentContext() {
 }
 
 void getOverridable(DUContext* base, DUContext* current, QMap< QPair<IndexedType, IndexedString>, KDevelop::CompletionTreeItemPointer >& overridable, CodeCompletionContext::Ptr completionContext) {
+  if(!current)
+    return;
+  
   foreach(Declaration* decl, current->localDeclarations()) {
     ClassFunctionDeclaration* classFun = dynamic_cast<ClassFunctionDeclaration*>(decl);
     if(classFun && (classFun->isVirtual() || classFun->isConstructor())) {
@@ -1646,6 +1671,9 @@ bool  CodeCompletionContext::filterDeclaration(Declaration* decl, DUContext* dec
   
   static IndexedIdentifier friendIdentifier(Identifier("friend"));
   
+  if(decl->indexedIdentifier().isEmpty()) //Filter out nameless declarations
+    return false;
+  
   if(decl->indexedIdentifier() == friendIdentifier)
     return false;
   
@@ -1682,8 +1710,8 @@ bool  CodeCompletionContext::filterDeclaration(ClassMemberDeclaration* decl, DUC
 
 void CodeCompletionContext::replaceCurrentAccess(QString old, QString _new)
 {
-  //We must not change the document from within the background, so we use a queued connection
-  QMetaObject::invokeMethod(new CppUtils::ReplaceCurrentAccess, "exec", Qt::QueuedConnection, Q_ARG(KUrl, m_duContext->url().toUrl()), Q_ARG(QString, old), Q_ARG(QString, _new));
+  //We must not change the document from within the background, so we use a queued connection to an object created in the foregroud
+  QMetaObject::invokeMethod(&accessReplacer, "exec", Qt::QueuedConnection, Q_ARG(KUrl, m_duContext->url().toUrl()), Q_ARG(QString, old), Q_ARG(QString, _new));
 }
 
 int CodeCompletionContext::matchPosition() const {
