@@ -104,20 +104,22 @@ MissingIncludeCompletionWorker* MissingIncludeCompletionModel::worker() const {
 }
 
 void MissingIncludeCompletionModel::completionInvokedInternal(KTextEditor::View* view, const KTextEditor::Range& range, KTextEditor::CodeCompletionModel::InvocationType invocationType, const KUrl& url) {
+  Q_UNUSED(view);
+  Q_UNUSED(range);
+  Q_UNUSED(invocationType);
+  Q_UNUSED(url);
   QMutexLocker lock(&worker()->mutex);
   
 //   CodeCompletionModel::completionInvokedInternal(view, range, invocationType, url);
   clear();
 }
 
-#if KDE_IS_VERSION(4,2,62)
 KTextEditor::CodeCompletionModelControllerInterface2::MatchReaction MissingIncludeCompletionModel::matchingItem(const QModelIndex& matched) {
   Q_UNUSED(matched);
   //When something in this model matches, don't hide the completion-list
   kDebug() << "checking reaction";
   return None;
 }
-#endif
 
 MissingIncludeCompletionWorker::MissingIncludeCompletionWorker(QObject* parent) : KDevelop::CodeCompletionWorker(parent), mutex(QMutex::Recursive) {
 }
@@ -159,7 +161,7 @@ QString MissingIncludeCompletionModel::filterString(KTextEditor::View* view, con
 }
 
 void MissingIncludeCompletionWorker::doSpecialProcessing(unsigned int data) {
-  
+  Q_UNUSED(data);
   QMutexLocker localLock(&mutex);
   
   kDebug() << context.data() << aborting() << localExpression << prefixExpression;
