@@ -194,6 +194,16 @@ void DeclarationBuilder::visitFunctionDeclaration(FunctionDefinitionAST* node)
   popSpecifiers();
 }
 
+//Visitor that clears the ducontext from all AST nodes
+struct ClearDUContextVisitor : public DefaultVisitor {
+
+  virtual void visit(AST* node) {
+    if(node)
+      node->ducontext = 0;
+    DefaultVisitor::visit(node);
+  }
+};
+
 void DeclarationBuilder::visitInitDeclarator(InitDeclaratorAST *node)
 {
   PushValue<bool> setHasInitialize(m_declarationHasInitializer, (bool)node->initializer);
@@ -219,8 +229,20 @@ void DeclarationBuilder::visitInitDeclarator(InitDeclaratorAST *node)
     node->declarator->parameter_is_initializer = !checkParameterDeclarationClause(node->declarator->parameter_declaration_clause);
     closePrefixContext(id);
     
+    
+    
     if(tempContext != previous) {
-      delete tempContext;
+      
+      //We remove all of its traces from the AST using ClearDUContextVisitor.
+      ClearDUContextVisitor clear;
+      clear.visit(node);
+
+      ///@todo We don't delete the tempContext, as that may cause crashes. Problem: This leaves garbage in the duchain
+      ///@todo Solve the redundancy issue once and for all, properly, using a SimpleDeclarationOrFunctionDeclarationAST or similar.
+      
+      //Since we don't delete the temporary context, at least collapse its range.
+      tempContext->setRange(SimpleRange(tempContext->range().start, tempContext->range().end));
+      
       setLastContext(previousLast);
       m_importedParentContexts = importedParentContexts;
     }
@@ -743,6 +765,8 @@ void DeclarationBuilder::closeDeclaration(bool forceInstance)
       currentDeclaration()->setType(type);
     }else{
       currentDeclaration()->setAbstractType(AbstractType::Ptr());
+      if(dynamic_cast<ClassDeclaration*>(currentDeclaration()))
+        currentDeclaration()->setKind(Declaration::Type);
     }
     if(TemplateDeclaration* templateDecl = dynamic_cast<TemplateDeclaration*>(currentDeclaration())) {
       //The context etc. may have been filled with new items, and the declaration may have been searched unsuccessfully, or wrong instantiations created.
@@ -1237,14 +1261,13 @@ void DeclarationBuilder::visitElaboratedTypeSpecifier(ElaboratedTypeSpecifierAST
 
         declarations = currentContext()->findDeclarations( id, pos);
 
-        if(declarations.isEmpty()) {
-          //We haven't found a declaration, so insert a forward-declaration in the global scope
-          forwardDeclarationGlobal = true;
-        }else{
-          //We have found a declaration. Do not create a new one, instead use the declarations type.
-          if(declarations.first()->abstractType()) {
-            //This belongs into the type-builder, but it's much easier to do here, since we already have all the information
-            ///@todo See above, only search for fitting declarations(of structure/enum/class/union type)
+        forwardDeclarationGlobal = true;
+        
+        //If a good declaration has been found, use its type. Else, create a new forward-declaration.
+        foreach(Declaration* decl, declarations)
+        {
+          if((decl->topContext() != currentContext()->topContext() || wasEncountered(decl)) && decl->abstractType())
+          {
             injectType(declarations.first()->abstractType());
             
             if( isFriendDeclaration ) {
@@ -1252,8 +1275,6 @@ void DeclarationBuilder::visitElaboratedTypeSpecifier(ElaboratedTypeSpecifierAST
               createFriendDeclaration(node);
             }
             return;
-          }else{
-            kDebug(9007) << "Error: Bad declaration";
           }
         }
       }
