@@ -37,8 +37,8 @@
 using namespace KDevelop;
 using namespace Cpp;
 
-NameASTVisitor::NameASTVisitor(ParseSession* session, Cpp::ExpressionVisitor* visitor, const KDevelop::DUContext* context, const KDevelop::TopDUContext* source, const SimpleCursor& position, KDevelop::DUContext::SearchFlags localSearchFlags, bool debug )
-: m_session(session), m_visitor(visitor), m_context(context), m_source(source), m_find(m_context, m_source, localSearchFlags, SimpleCursor(position) ), m_debug(debug), m_finalName(0)
+NameASTVisitor::NameASTVisitor(ParseSession* session, Cpp::ExpressionVisitor* visitor, const KDevelop::DUContext* context, const KDevelop::TopDUContext* source, const KDevelop::DUContext* localVisibilityContext, const SimpleCursor& position, KDevelop::DUContext::SearchFlags localSearchFlags, bool debug )
+: m_session(session), m_visitor(visitor), m_context(context), m_source(source), m_localContext(localVisibilityContext), m_find(m_context, m_source, localSearchFlags, SimpleCursor(position) ), m_debug(debug), m_finalName(0)
 {
   m_flags = localSearchFlags;
   m_stopSearch = false;
@@ -128,8 +128,13 @@ void NameASTVisitor::visitUnqualifiedName(UnqualifiedNameAST *node)
   } else {
     if(node == m_finalName) {
       if(m_visitor) { //Create a zero use, which will be highlighted as an error
-        m_visitor->newUse(node, node->id, node->id+1, DeclarationPointer());
-        ///@todo Eventually report a problem, but then we don't need the zero use
+        bool createUse = false;
+        {
+          LOCKDUCHAIN;
+          createUse = !m_foundSomething || !Cpp::isTemplateDependent(m_foundSomething.data());
+        }
+        if(createUse)
+          m_visitor->newUse(node, node->id, node->id+1, DeclarationPointer());
       }
       
       if( m_debug )
@@ -138,6 +143,10 @@ void NameASTVisitor::visitUnqualifiedName(UnqualifiedNameAST *node)
   }
 
   _M_name.push(m_currentIdentifier);
+  
+  if(!m_find.lastDeclarations().isEmpty()) {
+    m_foundSomething = m_find.lastDeclarations().first();
+  }
 }
 
 TypeSpecifierAST* NameASTVisitor::lastTypeSpecifier() const {
@@ -165,7 +174,7 @@ ExpressionEvaluationResult NameASTVisitor::processTemplateArgument(TemplateArgum
     if(!m_visitor) {
       m_visitor = new ExpressionVisitor(m_session, m_source);
       ownVisitor = true;
-      node->expression->ducontext = const_cast<DUContext*>(m_context);
+      node->expression->ducontext = const_cast<DUContext*>(m_localContext);
     }
     
     m_visitor->visit( node->expression );
@@ -196,8 +205,7 @@ ExpressionEvaluationResult NameASTVisitor::processTemplateArgument(TemplateArgum
     
   } else if( node->type_id )
   {
-    TypeASTVisitor v( m_session, m_visitor, m_context, m_source, m_debug );
-    v.setSearchFlags(m_flags);
+    TypeASTVisitor v( m_session, m_visitor, m_localContext, m_source, m_localContext, m_debug );
     v.run( node->type_id );
 
     if(v.stoppedSearch()) {
@@ -296,3 +304,9 @@ void NameASTVisitor::run(NameAST *node, bool skipLastNamePart)
   LOCKDUCHAIN;
   m_find.closeQualifiedIdentifier();
 }
+
+
+DeclarationPointer NameASTVisitor::foundSomething() const
+{
+  return m_foundSomething;
+}
