@@ -34,6 +34,7 @@
 #include <language/duchain/appendedlist.h>
 
 #include "templateparameterdeclaration.h"
+#include "qtfunctiondeclaration.h"
 #include "cppducontext.h"
 #include "expressionparser.h"
 #include <language/duchain/classdeclaration.h>
@@ -58,6 +59,7 @@ REGISTER_TEMPLATE_DECLARATION(TemplateParameterDeclaration)
 REGISTER_TEMPLATE_DECLARATION(ClassFunctionDeclaration)
 REGISTER_TEMPLATE_DECLARATION(ClassMemberDeclaration)
 REGISTER_TEMPLATE_DECLARATION(FunctionDeclaration)
+REGISTER_TEMPLATE_DECLARATION(QtFunctionDeclaration)
 REGISTER_TEMPLATE_DECLARATION(FunctionDefinition)
 REGISTER_TEMPLATE_DECLARATION(AliasDeclaration)
 REGISTER_TEMPLATE_DECLARATION(ForwardDeclaration)
@@ -572,7 +574,7 @@ CppDUContext<KDevelop::DUContext>* instantiateDeclarationAndContext( KDevelop::D
               newInstance.baseClass = newType->indexed();
               klass->replaceBaseClass( num, newInstance );
             } else {
-              kDebug(9007) << "Resolved bad base-class";
+//               kDebug(9007) << "Resolved bad base-class";
             }
           }
           ++num;
@@ -725,6 +727,7 @@ void TemplateDeclaration::deleteAllInstantiations()
 #define ifDebugMatching(x)
 
 QPair<unsigned int, TemplateDeclaration*> TemplateDeclaration::matchTemplateParameters(Cpp::InstantiationInformation info, const TopDUContext* source) {
+  Q_ASSERT(source);
   ///@todo match higher scopes
   InstantiationInformation specializedWith(this->specializedWith().information());
   
@@ -790,6 +793,9 @@ QPair<unsigned int, TemplateDeclaration*> TemplateDeclaration::matchTemplatePara
   if(templateContext->localDeclarations().count() != 0)
     instantiated = dynamic_cast<TemplateDeclaration*>(instantiate( instantiateWith, source, true ));
   
+  if(!instantiated)
+    return qMakePair(0u, (TemplateDeclaration*)0);
+  
   ifDebugMatching( kDebug() << "instantiated:" << dynamic_cast<Declaration*>(instantiated)->toString(); )
   
   InstantiationInformation instantiationSpecializedWith(instantiated->specializedWith().information());
@@ -834,15 +840,18 @@ Declaration* TemplateDeclaration::instantiate( const InstantiationInformation& _
       if(*it) {
         return dynamic_cast<Declaration*>(*it);
       }else{
-        ///@todo What the same thing is instantiated twice in parralel? Then this may trigger as well, altough one side should wait
+        ///@todo What if the same thing is instantiated twice in parralel? Then this may trigger as well, altough one side should wait
         ///We are currently instantiating this declaration with the same template arguments. This would lead to an assertion.
         kDebug() << "tried to recursively instantiate" << dynamic_cast<Declaration*>(this)->toString() << "with" << templateArguments.toString();
         ///Maybe problematic, because the returned declaration is not in the correct context etc.
-        return dynamic_cast<Declaration*>(this);
+        return 0;
       }
     }
   }
   
+  if(!source)
+    return 0;
+  
   DUContext* surroundingContext = dynamic_cast<const Declaration*>(this)->context();
   if(!surroundingContext) {
     kDebug() << "Declaration has no context:" << dynamic_cast<Declaration*>(this)->qualifiedIdentifier().toString() << dynamic_cast<Declaration*>(this)->toString();
@@ -1061,8 +1070,7 @@ Declaration* SpecialTemplateDeclaration<ForwardDeclaration>::resolve(const TopDU
       Declaration* baseResolved = instantiatedFrom->resolve(topContext);
       TemplateDeclaration* baseTemplate = dynamic_cast<TemplateDeclaration*>(baseResolved);
       if( baseResolved && baseTemplate ) {
-        Declaration* ret = baseTemplate->instantiate(instantiatedWith().information(), topContext ? topContext : this->topContext());
-        return ret;
+        return baseTemplate->instantiate(instantiatedWith().information(), topContext ? topContext : this->topContext());
       }else{
           //Forward-declaration was not resolved
           return 0;
