@@ -214,26 +214,53 @@ CppLanguageSupport::CppLanguageSupport( QObject* parent, const QVariantList& /*a
     m_assistant = new Cpp::StaticCodeAssistant;
 }
 
-///@todo Make this work again with non-class declarations/definitions
 void CppLanguageSupport::switchDefinitionDeclaration()
 {
   kDebug(9007) << "switching definition/declaration";
+
+  KUrl docUrl;
+  SimpleCursor cursor;
+  
   ///Step 1: Find the current top-level context of type DUContext::Other(the highest code-context).
   ///-- If it belongs to a function-declaration or definition, it can be retrieved through owner(), and we are in a definition.
   ///-- If no such context could be found, search for a declaration on the same line as the cursor, and switch to the according definition
-  KDevelop::IDocument* doc = core()->documentController()->activeDocument();
-  if(!doc || !doc->textDocument() || !doc->textDocument()->activeView()) {
-    kDebug(9007) << "No active document";
-    return;
+  
+  {
+    KDevelop::IDocument* doc = core()->documentController()->activeDocument();
+    if(!doc || !doc->textDocument() || !doc->textDocument()->activeView()) {
+      kDebug(9007) << "No active document";
+      return;
+    }
+    
+    docUrl = doc->textDocument()->url();
+    cursor = SimpleCursor(doc->textDocument()->activeView()->cursorPosition()); 
   }
-  kDebug(9007) << "Document:" << doc->url();
+  
+  KUrl switchCandidate = CppUtils::sourceOrHeaderCandidate(docUrl);
+  
+  if(switchCandidate.isValid())
+  {
+    
+    DUChainReadLocker lock;
+
+    //If the file has not been parsed yet, update it
+    TopDUContext* ctx = standardContext(docUrl);
+    //At least 'VisibleDeclarationsAndContexts' is required so we can do a switch
+    if(!ctx || (ctx->parsingEnvironmentFile() && !ctx->parsingEnvironmentFile()->featuresSatisfied(TopDUContext::VisibleDeclarationsAndContexts)))
+    {
+      lock.unlock();
+      kDebug(9007) << "Parsing switch-candidate before switching" << switchCandidate;
+      DUChain::self()->waitForUpdate(IndexedString(switchCandidate), TopDUContext::VisibleDeclarationsAndContexts);
+    }
+  }
+  
+  kDebug(9007) << "Document:" << docUrl;
 
   DUChainReadLocker lock(DUChain::lock());
 
-  TopDUContext* standardCtx = standardContext(doc->url());
+  TopDUContext* standardCtx = standardContext(docUrl);
   if(standardCtx) {
     Declaration* definition = 0;
-    SimpleCursor cursor = SimpleCursor(doc->textDocument()->activeView()->cursorPosition());
 
     DUContext* ctx = standardCtx->findContext(cursor);
     if(!ctx)
@@ -286,13 +313,12 @@ void CppLanguageSupport::switchDefinitionDeclaration()
     kDebug(9007) << "Got no context for the current document";
   }
 
-  Declaration* def = definitionForCursorDeclaration(SimpleCursor(doc->textDocument()->activeView()->cursorPosition()), doc->url());
+  Declaration* def = definitionForCursorDeclaration(cursor, docUrl);
 
   if(def) {
     KUrl url(def->url().str());
     KTextEditor::Range targetRange = def->range().textRange();
 
-    ///@todo If the cursor is already in the target context, do not move it.
     if(def->internalContext()) {
       targetRange.end() = def->internalContext()->range().end.textCursor();
     }else{
@@ -317,10 +343,9 @@ void CppLanguageSupport::switchDefinitionDeclaration()
 
   lock.unlock();
   ///- If no definition/declaration could be found to switch to, just switch the document using normal header/source heuristic by file-extension
-  KUrl url = CppUtils::sourceOrHeaderCandidate(doc->textDocument()->url());
 
-  if(url.isValid()) {
-    core()->documentController()->openDocument(url);
+  if(switchCandidate.isValid()) {
+    core()->documentController()->openDocument(switchCandidate);
   }else{
     kDebug(9007) << "Found no source/header candidate to switch";
   }
@@ -379,7 +404,7 @@ KDevelop::ILanguage *CppLanguageSupport::language()
     return core()->languageController()->language(name());
 }
 
-TopDUContext* CppLanguageSupport::standardContext(const KUrl& url, bool allowProxyContext)
+TopDUContext* CppLanguageSupport::standardContext(const KUrl& url, bool proxyContext)
 {
   DUChainReadLocker lock(DUChain::lock());
   const ParsingEnvironment* env = PreprocessJob::standardEnvironment();
@@ -397,7 +422,7 @@ TopDUContext* CppLanguageSupport::standardContext(const KUrl& url, bool allowPro
       top = candidates[0];
   }
 
-  if(top && (top->parsingEnvironmentFile() && top->parsingEnvironmentFile()->isProxyContext()) && !allowProxyContext)
+  if(top && (top->parsingEnvironmentFile() && top->parsingEnvironmentFile()->isProxyContext()) && !proxyContext)
   {
     if(!top->importedParentContexts().isEmpty())
     {
