@@ -136,7 +136,7 @@ void CPPParseJob::setNeedUpdateEverything(bool need) {
 
 CPPParseJob::CPPParseJob( const KUrl &url,
                     PreprocessJob* parentPreprocessor )
-        : KDevelop::ParseJob( url, 0 ),
+        : KDevelop::ParseJob( url ),
         m_needUpdateEverything( false ),
         m_parentPreprocessor( parentPreprocessor ),
         m_session( new ParseSession ),
@@ -522,41 +522,61 @@ void CPPInternalParseJob::run()
 
     if(!parentJob()->keepDuchain()) {
 
+      TopDUContext::Features newFeatures = parentJob()->minimumFeatures();
+      if(contentContext)
+        newFeatures = (TopDUContext::Features)(newFeatures | contentContext->features());
+
+      if(newFeatures & TopDUContext::ForceUpdate)
+        kDebug() << "update enforced";
+
+      ///At some point, we have to give up on features again, else processing will be just too slow.
+      ///Simple solution for now: Always go down to the minimum required level.
+      if(!contentContext || !contentContext->smartRange())
+        newFeatures = parentJob()->minimumFeatures();
+
+      bool keepAST = newFeatures & TopDUContext::AST;
+      
+      //Remove update-flags like 'Recursive' or 'ForceUpdate', and the AST flag
+      newFeatures = (TopDUContext::Features)(newFeatures & TopDUContext::AllDeclarationsContextsAndUses);
+      
       TranslationUnitAST* ast = 0L;
 
       Control control;
       Parser parser(&control);
 
-      ast = parser.parse( parentJob()->parseSession().data() );
+      if(newFeatures != TopDUContext::Empty)
+      {
+        ast = parser.parse( parentJob()->parseSession().data() );
 
-      //This will be set to true if the duchain data should be left untouched
-      if(ast->hadMissingCompoundTokens && updatingContentContext) {
-        //Make sure we don't update into a completely invalid state where everything is invalidated temporarily.
-        DUChainWriteLocker l(DUChain::lock());
+        //This will be set to true if the duchain data should be left untouched
+        if(ast->hadMissingCompoundTokens && updatingContentContext) {
+          //Make sure we don't update into a completely invalid state where everything is invalidated temporarily.
+          DUChainWriteLocker l(DUChain::lock());
 
-        if((updatingContentContext->features() & parentJob()->minimumFeatures()) ==  parentJob()->minimumFeatures() &&
-            updatingContentContext->smartRange() &&
-            updatingContentContext->parsingEnvironmentFile()->modificationRevision().modificationTime == ModificationRevision::revisionForFile(updatingContentContext->url()).modificationTime) {
-          kDebug() << "not processing" << updatingContentContext->url().str() << "because of missing compound tokens";
-          ICore::self()->uiController()->showErrorMessage(i18n("Not updating duchain for %1", parentJob()->document().toUrl().fileName()), 1);
-          l.unlock();
-          doNotChangeDUChain = true;
-          ProblemPointer problem(new Problem);
-          problem->setSource(ProblemData::Parser);
-          problem->setDescription("Not updating the DUChain because of serious document inconsistency");
-          control.reportProblem(problem);
+          if((updatingContentContext->features() & parentJob()->minimumFeatures()) ==  parentJob()->minimumFeatures() &&
+              updatingContentContext->smartRange() &&
+              updatingContentContext->parsingEnvironmentFile()->modificationRevision().modificationTime == ModificationRevision::revisionForFile(updatingContentContext->url()).modificationTime) {
+            kDebug() << "not processing" << updatingContentContext->url().str() << "because of missing compound tokens";
+            ICore::self()->uiController()->showErrorMessage(i18n("Not updating duchain for %1", parentJob()->document().toUrl().fileName()), 1);
+            l.unlock();
+            doNotChangeDUChain = true;
+            ProblemPointer problem(new Problem);
+            problem->setSource(ProblemData::Parser);
+            problem->setDescription("Not updating the DUChain because of serious document inconsistency");
+            control.reportProblem(problem);
+          }
         }
-      }
 
-      if (parentJob()->abortRequested())
-          return /*parentJob()->abortJob()*/;
+        if (parentJob()->abortRequested())
+            return /*parentJob()->abortJob()*/;
 
-      if ( ast ) {
-          ast->session = parentJob()->parseSession().data();
+        if ( ast ) {
+            ast->session = parentJob()->parseSession().data();
 #ifdef DUMP_AST
-          DumpTree dump;
-          dump.dump(ast, parentJob()->parseSession()->token_stream);
+            DumpTree dump;
+            dump.dump(ast, parentJob()->parseSession()->token_stream);
 #endif
+        }
       }
 
       CppEditorIntegrator editor(parentJob()->parseSession().data());
@@ -602,24 +622,21 @@ void CPPInternalParseJob::run()
 
       DeclarationBuilder declarationBuilder(&editor);
 
-      TopDUContext::Features newFeatures = parentJob()->minimumFeatures();
-      if(contentContext)
-        newFeatures = (TopDUContext::Features)(newFeatures | contentContext->features());
-
-      if(newFeatures & TopDUContext::ForceUpdate)
-        kDebug() << "update enforced";
-
-      ///At some point, we have to give up on features again, else processing will be just too slow.
-      ///Simple solution for now: Always go down to the minimum required level.
-      ///@todo Think of a good mechanism to decide when we want to drop features, and when we want to keep them.
-      if(!contentContext || !contentContext->smartRange())
-        newFeatures = parentJob()->minimumFeatures();
-
-      if(newFeatures == TopDUContext::VisibleDeclarationsAndContexts)
+      if(newFeatures == TopDUContext::VisibleDeclarationsAndContexts) {
         declarationBuilder.setOnlyComputeVisible(true); //Only visible declarations/contexts need to be built.
+      }
+      else if(newFeatures == TopDUContext::SimplifiedVisibleDeclarationsAndContexts)
+      {
+        declarationBuilder.setOnlyComputeVisible(true);
+        declarationBuilder.setComputeSimplified(true);
+        kDebug() << "computing simplified";
+      }else if(newFeatures == TopDUContext::Empty) {
+        kDebug() << "computing empty";
+        declarationBuilder.setComputeEmpty(true);
+      }
 
 
-      if(newFeatures & TopDUContext::AST)
+      if(keepAST)
         declarationBuilder.setMapAst(true); //Set the property to map the AST & DUChain
 
       if(!doNotChangeDUChain) {
@@ -701,16 +718,21 @@ void CPPInternalParseJob::run()
         }
 
         if (!parentJob()->abortRequested()) {
-          if (newFeatures & TopDUContext::AllDeclarationsContextsAndUses) {
+          if ((newFeatures & TopDUContext::AllDeclarationsContextsAndUses) == TopDUContext::AllDeclarationsContextsAndUses) {
               parentJob()->setLocalProgress(0.5, i18n("Building uses"));
 
               UseBuilder useBuilder(&editor);
-              useBuilder.setMapAst(newFeatures & TopDUContext::AST);
+              useBuilder.setMapAst(keepAST);
               useBuilder.buildUses(ast);
               DUChainWriteLocker l(DUChain::lock());
               foreach(KDevelop::ProblemPointer problem, useBuilder.problems())
                 contentContext->addProblem(problem);
+          }else{
+              //Delete existing uses
+              DUChainWriteLocker lock( DUChain::lock() );
+              contentContext->deleteUsesRecursively();
           }
+          
           if (!parentJob()->abortRequested() && editor.smart()) {
 
             if ( parentJob()->cpp() && parentJob()->cpp()->codeHighlighting() )
@@ -730,11 +752,10 @@ void CPPInternalParseJob::run()
         contentContext->setFlags( (TopDUContext::Flags)(contentContext->flags() & (~TopDUContext::UpdatingContext)) );
 
         //Now that the Ast is fully built, add it to the TopDUContext if requested
-        if(newFeatures & TopDUContext::AST)
+        if(keepAST)
         {
-          kDebug() << "AST Is being kept for TopDUContext: ";
+          kDebug() << "AST Is being kept for" << parentJob()->document().toUrl();
           parentJob()->parseSession()->setASTNodeParents();
-          //!@todo Figure out a better way to convert to supperclass pointer
           contentContext->setAst(IAstContainer::Ptr( parentJob()->parseSession().data() ));
         }
 
@@ -746,6 +767,11 @@ void CPPInternalParseJob::run()
         return /*parentJob()->abortJob()*/;
 
     }else{
+      {
+        DUChainWriteLocker l(DUChain::lock());
+        if(proxyContext && contentContext)
+          proxyContext->setFeatures(contentContext->features());
+      }
       kDebug() << "keeping duchain";
       highlightIfNeeded();
     }
@@ -974,5 +1000,26 @@ void CPPParseJob::setIncludeStack(const QStack< DocumentCursor > & includeStack)
   m_includeStack = includeStack;
 }
 
+TopDUContext::Features CPPParseJob::standardMinimumFeatures() const
+{
+    return TopDUContext::SimplifiedVisibleDeclarationsAndContexts;
+}
+
+TopDUContext::Features CPPParseJob::slaveMinimumFeatures() const
+{
+    TopDUContext::Features slaveMinimumFeatures = standardMinimumFeatures();
+    
+    if(minimumFeatures() & TopDUContext::Recursive)
+      slaveMinimumFeatures = (TopDUContext::Features)(minimumFeatures() & (~TopDUContext::ForceUpdate));
+    else if((minimumFeatures() & TopDUContext::VisibleDeclarationsAndContexts) == TopDUContext::VisibleDeclarationsAndContexts)
+      slaveMinimumFeatures = TopDUContext::VisibleDeclarationsAndContexts;
+    
+    if((minimumFeatures() & TopDUContext::ForceUpdateRecursive) == TopDUContext::ForceUpdateRecursive)
+      slaveMinimumFeatures = (TopDUContext::Features)(slaveMinimumFeatures | TopDUContext::ForceUpdateRecursive);
+
+    //The selected minimum features are required on all imported contexts recursively
+    return (TopDUContext::Features)(slaveMinimumFeatures | TopDUContext::Recursive);
+}
+
 #include "cppparsejob.moc"
 
