@@ -51,26 +51,26 @@ QPair<rpp::Anchor, uint> LocationTable::positionAt(std::size_t offset, const Pre
   if(!ret.anchor.collapsed)
     for(std::size_t a = ret.position; a < offset; ++a)
       ret.anchor.column += KDevelop::IndexedString::fromIndex(contents[a]).length();
-  
+
   uint room = 0;
   if(ret.nextPosition)
     if(ret.nextAnchor.line == ret.anchor.line && ret.nextAnchor.column > ret.anchor.column)
       room = ret.nextAnchor.column - ret.anchor.column;
-    
+
   return qMakePair(ret.anchor, room);
 }
 
 void LocationTable::anchor(std::size_t offset, Anchor anchor, const PreprocessedContents* contents)
 {
   Q_ASSERT(!offset || !anchor.column || contents);
-  
+
   if (offset && anchor.column) {
     // Check to see if it's different to what we already know
     QPair<rpp::Anchor, uint> known = positionAt(offset, *contents);
     if (known.first == anchor && !anchor.collapsed && known.first.macroExpansion == anchor.macroExpansion)
       return;
   }
-  m_currentOffset = m_offsetTable.insert(offset, anchor);
+  m_currentOffset = OffsetTable::ConstIterator(m_offsetTable.insert(offset, anchor));
 }
 
 LocationTable::AnchorInTable LocationTable::anchorForOffset(std::size_t offset, bool collapseIfMacroExpansion) const
@@ -122,7 +122,7 @@ LocationTable::AnchorInTable LocationTable::anchorForOffset(std::size_t offset,
   //kDebug() << k_funcinfo << offset << "found" << m_currentOffset.key();
   if (m_currentOffset == constEnd)
     --m_currentOffset;
-  
+
   if (m_currentOffset.key() > offset)
     --m_currentOffset;
 
@@ -131,20 +131,20 @@ LocationTable::AnchorInTable LocationTable::anchorForOffset(std::size_t offset,
   Anchor ret = m_currentOffset.value();
   if(ret.macroExpansion.isValid() && collapseIfMacroExpansion)
     ret.collapsed = true;
-  
+
   AnchorInTable retItem;
   retItem.position = m_currentOffset.key();
   retItem.anchor = ret;
-  
+
   ++m_currentOffset;
-  
+
   if(m_currentOffset == constEnd) {
     retItem.nextPosition = 0;
   }else{
     retItem.nextPosition = m_currentOffset.key();
     retItem.nextAnchor = m_currentOffset.value();
   }
-  
+
   return retItem;
 }
 
@@ -162,14 +162,14 @@ void LocationTable::splitByAnchors(const PreprocessedContents& text, const Ancho
 
   Anchor currentAnchor = Anchor(textStartPosition);
   size_t currentOffset = 0;
-  
+
   QMapIterator<std::size_t, Anchor> it = m_offsetTable;
 
   while (currentOffset < (size_t)text.size())
   {
     Anchor nextAnchor(KDevelop::SimpleCursor::invalid());
     size_t nextOffset;
-    
+
     if(it.hasNext()) {
       it.next();
       nextOffset = it.key();
@@ -183,7 +183,7 @@ void LocationTable::splitByAnchors(const PreprocessedContents& text, const Ancho
       strings.append(text.mid(currentOffset, nextOffset-currentOffset));
       anchors.append(currentAnchor);
     }
-    
+
     currentOffset = nextOffset;
     currentAnchor = nextAnchor;
   }
