@@ -61,7 +61,7 @@ enum TOKEN_KIND
     Token_dynamic_cast,
     Token_ellipsis,
     Token_else,
-    Token_emit,
+    //Token_emit, // Disable emit as its also a valid function call and the token isn't used anywhere
     Token_enum,
     Token_eq,
     Token_explicit,
@@ -130,6 +130,7 @@ enum TOKEN_KIND
     Token_whitespaces,
     Token_xor,
     Token_xor_eq,
+    Token___qt_sig_slot__,
 
     TOKEN_KIND_COUNT
 };
@@ -137,5 +138,8 @@ enum TOKEN_KIND
 /**@return human-readable name of the token.*/
 KDEVCPPPARSER_EXPORT char const *token_name(int token);
 
+/**@return text corresponding to the token.*/
+KDEVCPPPARSER_EXPORT char const *token_text(int token);
+
 #endif
 
