@@ -145,13 +145,8 @@ void PreprocessJob::run()
     rpp::pp preprocessor(this);
     m_pp = &preprocessor;
 
-    // Create a new macro block if this is the master preprocess-job
-    if( parentJob()->masterJob() == parentJob() )
-        parentJob()->parseSession()->macros = new rpp::MacroBlock(0);
-    
     //Eventually initialize the environment with the parent-environment to get its macros
     m_currentEnvironment = new CppPreprocessEnvironment( &preprocessor, m_firstEnvironmentFile );
-    m_currentEnvironment->enterBlock(parentJob()->masterJob()->parseSession()->macros);
 
     //If we are included from another preprocessor, copy its macros
     if( parentJob()->parentPreprocessor() ) {
@@ -171,11 +166,14 @@ void PreprocessJob::run()
         ///Find a context that can be updated, and eventually break processing right here, if we notice we don't need to update
         KDevelop::DUChainReadLocker readLock(KDevelop::DUChain::lock());
         
+        //Make sure we only match proxy-contexts for updating
+        m_currentEnvironment->setIdentityOffsetRestriction(m_firstEnvironmentFile->identityOffset());
+        
         updatingEnvironmentFile = KDevelop::ParsingEnvironmentFilePointer( KDevelop::DUChain::self()->environmentFileForDocument(parentJob()->document(), m_currentEnvironment, (bool)m_secondEnvironmentFile) );
         
         if(parentJob()->masterJob() == parentJob() && updatingEnvironmentFile) {
           //Check whether we need to run at all, or whether the file is already up to date
-          if(updatingEnvironmentFile->featuresSatisfied(parentJob()->minimumFeatures())) {
+          if(updatingEnvironmentFile->featuresSatisfied(parentJob()->minimumFeatures()) && updatingEnvironmentFile->featuresSatisfied(parentJob()->slaveMinimumFeatures())) {
             KUrl localPath(parentJob()->document().toUrl());
             localPath.setFileName(QString());
             Cpp::EnvironmentFile* cppEnv = dynamic_cast<Cpp::EnvironmentFile*>(updatingEnvironmentFile.data());
@@ -313,7 +311,7 @@ TopDUContext* contentFromProxy(TopDUContext* ctx) {
         }
         if(ctx->importedParentContexts().isEmpty()) {
           kDebug() << "proxy-context for" << ctx->url().str() << "has no imports!" << ctx->ownIndex();
-          Q_ASSERT(0);
+          return 0;
         }
         Q_ASSERT(!ctx->importedParentContexts().isEmpty());
         return dynamic_cast<TopDUContext*>(ctx->importedParentContexts().first().context(0));
@@ -354,7 +352,7 @@ void PreprocessJob::headerSectionEndedInternal(rpp::Stream* stream)
         if(m_updatingEnvironmentFile)
           content = KDevelop::ReferencedTopDUContext(contentFromProxy(m_updatingEnvironmentFile->topContext()));
         else
-          content = KDevelop::DUChain::self()->chainForDocument(u, m_currentEnvironment, false, true);
+          content = KDevelop::DUChain::self()->chainForDocument(u, m_currentEnvironment);
 
         m_currentEnvironment->disableIdentityOffsetRestriction();
 
@@ -362,6 +360,8 @@ void PreprocessJob::headerSectionEndedInternal(rpp::Stream* stream)
             //We have found a content-context that we can use
             parentJob()->setUpdatingContentContext(content);
 
+            Q_ASSERT(!content->parsingEnvironmentFile()->isProxyContext());
+            
             Cpp::EnvironmentFilePointer contentEnvironment(dynamic_cast<Cpp::EnvironmentFile*>(content->parsingEnvironmentFile().data()));
             Q_ASSERT(m_updatingEnvironmentFile || contentEnvironment->identityOffset() == m_secondEnvironmentFile->identityOffset());            
 
@@ -369,7 +369,7 @@ void PreprocessJob::headerSectionEndedInternal(rpp::Stream* stream)
             KUrl localPath(parentJob()->document().str());
             localPath.setFileName(QString());
             
-            if(contentEnvironment->matchEnvironment(m_currentEnvironment) && !CppUtils::needsUpdate(contentEnvironment, localPath, parentJob()->includePathUrls()) && (!parentJob()->masterJob()->needUpdateEverything() || parentJob()->masterJob()->wasUpdated(content)) && (content->parsingEnvironmentFile()->featuresSatisfied(parentJob()->minimumFeatures())) ) {
+            if(contentEnvironment->matchEnvironment(m_currentEnvironment) && !CppUtils::needsUpdate(contentEnvironment, localPath, parentJob()->includePathUrls()) && (!parentJob()->masterJob()->needUpdateEverything() || parentJob()->masterJob()->wasUpdated(content)) && (content->parsingEnvironmentFile()->featuresSatisfied(parentJob()->minimumFeatures()) && content->parsingEnvironmentFile()->featuresSatisfied(parentJob()->slaveMinimumFeatures())) ) {
                 //We can completely re-use the specialized context:
                 m_secondEnvironmentFile = dynamic_cast<Cpp::EnvironmentFile*>(content->parsingEnvironmentFile().data());
                 m_updatingEnvironmentFile = m_secondEnvironmentFile;
@@ -419,16 +419,9 @@ rpp::Stream* PreprocessJob::sourceNeeded(QString& _fileName, IncludeType type, i
       }
     }
     
-    
     KUrl fileNameUrl(_fileName);
     
-    TopDUContext::Features slaveMinimumFeatures = TopDUContext::VisibleDeclarationsAndContexts;
-    if((parentJob()->minimumFeatures() & TopDUContext::AllDeclarationsContextsAndUsesForRecursive) == TopDUContext::AllDeclarationsContextsAndUsesForRecursive)
-      slaveMinimumFeatures = parentJob()->minimumFeatures();
-    
-    if((parentJob()->minimumFeatures() & TopDUContext::ForceUpdateRecursive) == TopDUContext::ForceUpdateRecursive)
-      slaveMinimumFeatures = (TopDUContext::Features)(slaveMinimumFeatures | TopDUContext::ForceUpdateRecursive);
-    
+    TopDUContext::Features slaveMinimumFeatures = parentJob()->slaveMinimumFeatures();
     QString fileName = fileNameUrl.pathOrUrl();
     
     if (checkAbort())
@@ -510,22 +503,30 @@ rpp::Stream* PreprocessJob::sourceNeeded(QString& _fileName, IncludeType type, i
               Cpp::EnvironmentFilePointer includedEnvironment(dynamic_cast<Cpp::EnvironmentFile*>(includedContext->parsingEnvironmentFile().data()));
               if( includedEnvironment ) {
                 updateNeeded = CppUtils::needsUpdate(includedEnvironment, localPath, parentJob()->includePathUrls());
+                //The ForceUpdateRecursive flag is removed before checking for satisfied features, so we can prevent double-updating through "wasUpdated()" below (see *1)
                 updateNeeded |= !includedEnvironment->featuresSatisfied((TopDUContext::Features)(slaveMinimumFeatures & (~TopDUContext::ForceUpdateRecursive)));
-                //Do not update again if ForceUpdate is given and the context was already updated during this run
+                //(*1) Do not update again if ForceUpdate is given and the context was already updated during this run
                 updateNeeded |= (slaveMinimumFeatures & TopDUContext::ForceUpdate) && !parentJob()->masterJob()->wasUpdated(includedContext.data());
                 
-                ///NEVER update when the file is header-guarded in the current environment, because else it will be emptied
+                #if 0
+                //If header-guards should be ignored, unguard the file
+                if(Cpp::EnvironmentManager::ignoreGuardsForImporting() &&
+                  !includedEnvironment->headerGuard().isEmpty() && m_currentEnvironment->macroNameSet().contains(includedEnvironment->headerGuard()))
+                {
+                  m_currentEnvironment->removeMacro(includedEnvironment->headerGuard());
+                }
+                #endif
+                
                 if(!includedEnvironment->headerGuard().isEmpty() && m_currentEnvironment->macroNameSet().contains(includedEnvironment->headerGuard())) {
                   updateForbidden = true;
-//                   kDebug() << "forbidding update of" << includedFile;
-                  updateNeeded = false;
+                  kDebug() << "forbidding update of" << includedFile;
+                  updateNeeded = false;         
                 }
               }
             }
         }
 
-        if( includedContext && (updateForbidden ||
-                               (!updateNeeded && (!parentJob()->masterJob()->needUpdateEverything() || parentJob()->masterJob()->wasUpdated(includedContext))) )) {
+        if( includedContext && (updateForbidden || (!updateNeeded && (!parentJob()->masterJob()->needUpdateEverything() || parentJob()->masterJob()->wasUpdated(includedContext)))) ) {
             ifDebug( kDebug(9007) << "PreprocessJob" << parentJob()->document().str() << ": took included file from the du-chain" << fileName; )
 
             KDevelop::DUChainReadLocker readLock(KDevelop::DUChain::lock());
@@ -540,7 +541,6 @@ rpp::Stream* PreprocessJob::sourceNeeded(QString& _fileName, IncludeType type, i
                 ifDebug( kDebug(9007) << "preprocessjob: included file" << includedFile << "found in du-chain, but it has no parse-environment information, or it was not parsed by c++ support"; )
             }
         } else {
-            Q_ASSERT(!updateForbidden);
             if(updateNeeded)
               kDebug(9007) << "PreprocessJob" << parentJob()->document().str() << ": need to update" << includedFile;
             else if(parentJob()->masterJob()->needUpdateEverything() && includedContext)
