@@ -106,6 +106,60 @@ Declaration* TestCppCodeCompletion::findDeclaration(DUContext* context, const Qu
   return 0;
 }
 
+void TestCppCodeCompletion::testKeywords() {
+  QByteArray test = "struct Values { int Value1; int Value2; struct Sub { int SubValue; }; }; int test(int a) {}";
+
+  TopDUContext* context = parse(test, DumpNone);
+  DUChainWriteLocker lock(DUChain::lock());
+  QCOMPARE(context->childContexts().count(), 3);
+  
+  CompletionItemTester testCase(context->childContexts()[2], "switch (a) { case ");
+  QVERIFY(testCase.completionContext->isValid());
+  QCOMPARE(testCase.names, QStringList() << "a" << "Values" << "test");
+  CompletionItemTester testCase2(context->childContexts()[2], "switch (a) { case Values.");
+  QVERIFY(testCase2.completionContext->isValid());
+  QCOMPARE(testCase2.names, QStringList() << "Value1" << "Value2");
+  
+  CompletionItemTester testReturn(context->childContexts()[2], "return ");
+  QVERIFY(testReturn.completionContext->isValid());
+  QCOMPARE(testReturn.names, QStringList()  << "return int" << "a" << "Values" << "test");
+  CompletionItemTester testReturn2(context->childContexts()[2], "return Values.");
+  QVERIFY(testReturn2.completionContext->isValid());
+  QCOMPARE(testReturn2.names, QStringList() << "return int" << "Value1" << "Value2");
+  
+  CompletionItemTester testNew(context->childContexts()[2], "Values a = new ");
+  QVERIFY(testNew.completionContext->isValid());
+  QVERIFY(testNew.names.contains("Values"));
+  CompletionItemTester testNew2(context->childContexts()[2], "Values::Sub a = new Values::");
+  QVERIFY(testNew2.completionContext->isValid());
+  QCOMPARE(testNew2.names, QStringList() << "Value1" << "Value2" << "Sub" ); //A little odd to see Value1 & 2 here
+  
+  CompletionItemTester testElse(context->childContexts()[2], "if (a) {} else ");
+  QVERIFY(testElse.completionContext->isValid());
+  QCOMPARE(testElse.names, QStringList() << "a" << "Values" << "test");
+  CompletionItemTester testElse2(context->childContexts()[2], "if (a) {} else Values::");
+  QVERIFY(testElse2.completionContext->isValid());
+  QCOMPARE(testElse2.names, QStringList() << "Value1" << "Value2" << "Sub" );
+#if 0  
+  CompletionItemTester testThrow(context->childContexts()[2], "throw ");
+  QVERIFY(testThrow.completionContext->isValid());
+  QCOMPARE(testThrow.names, QStringList() << "a" << "Values" << "test");
+  CompletionItemTester testThrow2(context->childContexts()[2], "thow Values::");
+  QVERIFY(testThrow2.completionContext->isValid());
+  QCOMPARE(testThrow2.names, QStringList() << "Value1" << "Value2" << "Sub" );
+#endif
+  CompletionItemTester testDelete(context->childContexts()[2], "delete ");
+  QVERIFY(testDelete.completionContext->isValid());
+  QCOMPARE(testDelete.names, QStringList() << "a" << "Values" << "test");
+  CompletionItemTester testDelete2(context->childContexts()[2], "delete Values::");
+  QVERIFY(testDelete2.completionContext->isValid());
+  QCOMPARE(testDelete2.names, QStringList() << "Value1" << "Value2" << "Sub" );
+  
+  //TODO: emit, Q_EMIT;
+  
+  release(context);
+}
+
 void TestCppCodeCompletion::testArgumentMatching() {
   {
     QByteArray test = "struct A{ int m;}; void test(int q) { A a;  }";
@@ -263,7 +317,7 @@ void TestCppCodeCompletion::testAssistant() {
       QCOMPARE(mdp->type->containerContext.data(), context->childContexts()[0]);
       QCOMPARE(mdp->type->identifier().toString(), QString("member"));
       QVERIFY(mdp->type->assigned.type.isValid());
-      QCOMPARE(TypeUtils::removeConstants(mdp->type->assigned.type.abstractType())->toString(), QString("int"));
+      QCOMPARE(TypeUtils::removeConstants(mdp->type->assigned.type.abstractType(), context)->toString(), QString("int"));
     }
     release(context);
   }
@@ -280,7 +334,7 @@ void TestCppCodeCompletion::testAssistant() {
       QCOMPARE(mdp->type->containerContext.data(), context->childContexts()[0]);
       QCOMPARE(mdp->type->identifier().toString(), QString("value"));
       QVERIFY(mdp->type->assigned.type.isValid());
-      QCOMPARE(TypeUtils::removeConstants(mdp->type->assigned.type.abstractType())->toString(), QString("int"));
+      QCOMPARE(TypeUtils::removeConstants(mdp->type->assigned.type.abstractType(), context)->toString(), QString("int"));
       QCOMPARE(context->childContexts().count(), 3);
     }
     {
@@ -303,7 +357,7 @@ void TestCppCodeCompletion::testAssistant() {
       QCOMPARE(mdp->type->identifier().toString(), QString("value3"));
       QVERIFY(!mdp->type->assigned.type.isValid());
       QVERIFY(mdp->type->convertedTo.type.isValid());
-      QCOMPARE(TypeUtils::removeConstants(mdp->type->convertedTo.type.abstractType())->toString(), QString("int"));
+      QCOMPARE(TypeUtils::removeConstants(mdp->type->convertedTo.type.abstractType(), context)->toString(), QString("int"));
       QCOMPARE(context->childContexts().count(), 3);
     }
     release(context);
@@ -410,6 +464,7 @@ void TestCppCodeCompletion::testCompletionPrefix() {
     DUChainWriteLocker lock(DUChain::lock());
     QCOMPARE(top->childContexts().size(), 3);
     //Make sure the completion behind "for <" does not only show types
+    QVERIFY(CompletionItemTester(top->childContexts()[2], ";for(int a = 0; a <  t2->").names.contains("m"));
     QVERIFY(CompletionItemTester(top->childContexts()[2], ";for(int a = 0; a <  ").names.contains("t2"));
     //Make sure that only types are shown as template parameters
     QVERIFY(!CompletionItemTester(top->childContexts()[2], "Test<").names.contains("t2"));
@@ -593,7 +648,7 @@ void TestCppCodeCompletion::testCompletionBehindTypedeffedConstructor() {
     DUChainWriteLocker lock(DUChain::lock());
     QCOMPARE(top->childContexts().count(), 4);
     QCOMPARE(top->childContexts()[1]->localDeclarations().size(), 2);
-    
+
     //Member completion
     QCOMPARE(CompletionItemTester(top->childContexts()[3], "A<int>().").names.toSet(), (QStringList() << QString("m") << QString("A")).toSet());
     QCOMPARE(CompletionItemTester(top->childContexts()[3], "TInt().").names.toSet(), (QStringList() << QString("m") << QString("A")).toSet());
@@ -601,6 +656,7 @@ void TestCppCodeCompletion::testCompletionBehindTypedeffedConstructor() {
     //Argument-hints
     kDebug() << CompletionItemTester(top->childContexts()[3], "TInt(").parent().names;
     QVERIFY(CompletionItemTester(top->childContexts()[3], "TInt(").parent().names.contains("A"));
+    QVERIFY(CompletionItemTester(top->childContexts()[3], "TInt ti(").parent().names.contains("A"));
     
     release(top);
 }
@@ -1708,10 +1764,10 @@ void TestCppCodeCompletion::testPreprocessor() {
   IncludeFileList includes;
   
   {
-    QString a = "#define Q(c) c; char* q = #c; \n Q(int i;\n int c;)\n";
+    QString a = "#define Q(c) c; char* q = #c; \n Q(int i;\n char* c = \"a\";)\n";
     QString preprocessed = preprocess(HashedString(), a, includes);  
     kDebug() << "preprocessed:" << preprocessed;
-    QVERIFY(preprocessed.contains("\"int i;\\n int c;")); //The newline must have been escaped correctly
+    QVERIFY(preprocessed.contains("\"int i;\\n char* c = \\\"a\\\";")); //The newline must have been escaped correctly, and the string as well
     TopDUContext* top = parse(a.toLocal8Bit(), DumpNone);
     DUChainWriteLocker lock(DUChain::lock());
     kDebug() << top->localDeclarations()[0]->identifier().toString();
@@ -1890,14 +1946,6 @@ QString TestCppCodeCompletion::preprocess( const HashedString& url, const QStrin
     preprocessor.setEnvironment( currentEnvironment );
     currentEnvironment->setEnvironmentFile( environmentFile );
 
-    rpp::MacroBlock* macros = 0;
-    if(parent)
-      macros = parent->environment()->firstBlock();
-    else
-      macros = new rpp::MacroBlock(0);
-
-    preprocessor.environment()->enterBlock(macros);
-
     if( parent )
       preprocessor.environment()->swapMacros(parent->environment());
 
