@@ -79,8 +79,8 @@ void CMakeJob::start()
 
     setStandardToolView( KDevelop::IOutputView::BuildView );
     setBehaviours(KDevelop::IOutputView::AllowUserClose | KDevelop::IOutputView::AutoScroll );
-
-    setModel( new KDevelop::OutputModel(this), KDevelop::IOutputView::TakeOwnership );
+    KDevelop::OutputModel* m_model = new KDevelop::OutputModel(this);
+    setModel( m_model, KDevelop::IOutputView::TakeOwnership );
     startOutput();
 
     QString cmd = cmakeBinary( m_project );
@@ -101,6 +101,7 @@ void CMakeJob::start()
     connect( m_executor, SIGNAL( failed() ), this, SLOT( slotFailed() ) );
     connect( m_executor, SIGNAL( completed() ), this, SLOT( slotCompleted() ) );
     kDebug() << "Executing" << cmakeBinary( m_project ) << buildDirUrl.toLocalFile() << cmakeArguments( m_project );
+    m_model->appendLine( buildDirUrl.toLocalFile() + "> " + cmakeBinary( m_project ) + " " + cmakeArguments( m_project ).join(" ") );
     m_executor->start();
 }
 
@@ -148,13 +149,14 @@ QStringList CMakeJob::cmakeArguments( KDevelop::IProject* project )
     cmakecache.addPath("CMakeCache.txt");
     if( !QFileInfo( cmakecache.toLocalFile() ).exists() )
     {
-        KSharedConfig::Ptr cfg = project->projectConfiguration();
-        
-        KConfigGroup group(cfg.data(), "CMake");
         args << QString("-DCMAKE_INSTALL_PREFIX=%1").arg(CMake::currentInstallDir(project).toLocalFile());
         args << QString("-DCMAKE_BUILD_TYPE=%1").arg(CMake::currentBuildType(project));
         args << CMake::projectRoot(project).toLocalFile();
+    } else 
+    {
+        args << ".";
     }
+
     return args;
 }
 
