@@ -85,6 +85,8 @@
 #include <interfaces/idocumentation.h>
 #include "cmakeprojectdata.h"
 #include <cmakeconfig.h>
+#include <kio/copyjob.h>
+#include <KIO/NetAccess>
 
 using namespace KDevelop;
 
@@ -110,7 +112,7 @@ inline QString replaceBuildDir(QString in, QString buildDir)
     return in.replace("#[bin_dir]", buildDir);
 }
 
-inline QString replaceInstallDir(QString in, QString installDir)
+inline  QString replaceInstallDir(QString in, QString installDir)
 {
     return in.replace("#[install_dir]", installDir);
 }
@@ -513,29 +515,33 @@ QList<KDevelop::ProjectFolderItem*> CMakeManager::parse( KDevelop::ProjectFolder
                 if(data.properties[TARGET].contains(t.name) && data.properties[TARGET][t.name].contains("OUTPUT_NAME"))
                     outputName=data.properties[TARGET][t.name]["OUTPUT_NAME"].first();
                 
-                KUrl path;
+                QString path;
                 switch(t.type)
                 {
                     case Target::Library:
-                        path=KUrl(data.vm.value("CMAKE_LIBRARY_OUTPUT_DIRECTORY").join(QString()));
+                        path=data.vm.value("CMAKE_LIBRARY_OUTPUT_DIRECTORY").join(QString());
                         break;
                     case Target::Executable:
-                        path=KUrl(data.vm.value("CMAKE_RUNTIME_OUTPUT_DIRECTORY").join(QString()));
+                        path=data.vm.value("CMAKE_RUNTIME_OUTPUT_DIRECTORY").join(QString());
                         break;
                     case Target::Custom:
                         break;
                 }
                 
+                KUrl resolvedPath;
+                if(!path.isEmpty())
+                    resolvedPath=resolveSystemDirs(folder->project(), QStringList(path)).first();
+                
                 KDevelop::ProjectTargetItem* targetItem = 0;
                 switch(t.type)
                 {
                     case Target::Library:
                         targetItem = new CMakeLibraryTargetItem( item->project(), t.name,
-                                                                 folder, t.declaration, outputName, path );
+                                                                 folder, t.declaration, outputName, resolvedPath);
                         break;
                     case Target::Executable:
                         targetItem = new CMakeExecutableTargetItem( item->project(), t.name,
-                                                                    folder, t.declaration, outputName, path );
+                                                                    folder, t.declaration, outputName, resolvedPath);
                         break;
                     case Target::Custom:
                         targetItem = new CMakeCustomTargetItem( item->project(), t.name,
@@ -1168,10 +1174,13 @@ QWidget* CMakeManager::specialLanguageObjectNavigationWidget(const KUrl& url, co
         
         QString id=e->text(KTextEditor::Range(start, end));
         ICMakeDocumentation* docu=CMake::cmakeDocumentation();
-        KSharedPtr<IDocumentation> desc=docu->description(id, url);
-        if(!desc.isNull())
+        if( docu )
         {
-            doc=new CMakeNavigationWidget(top, desc);
+            KSharedPtr<IDocumentation> desc=docu->description(id, url);
+            if(!desc.isNull())
+            {
+                doc=new CMakeNavigationWidget(top, desc);
+            }
         }
     }
     
@@ -1201,9 +1210,16 @@ bool CMakeManager::renameFile(ProjectFileItem* it, const KUrl& newUrl)
 {
     ProjectTargetItem* target=static_cast<ProjectBaseItem*>(it->parent())->target();
     if(!target) {
-        it->setText(newUrl.fileName(KUrl::IgnoreTrailingSlash));
-        it->setUrl(newUrl);
-        return true;
+        KIO::CopyJob* job=KIO::move(it->url(), newUrl);
+        qDebug() << "pssss" << it->url() << "->" << newUrl;
+        bool ret=KIO::NetAccess::synchronousRun(job, 0);
+        
+        if(ret) {
+            it->project()->removeFromFileSet(IndexedString(it->url()));
+            it->setUrl(newUrl);
+            it->project()->addToFileSet(IndexedString(it->url()));
+        }
+        return ret;
     }
     
     CMakeFolderItem* folder=static_cast<CMakeFolderItem*>(target->parent());
@@ -1224,38 +1240,42 @@ bool CMakeManager::renameFile(ProjectFileItem* it, const KUrl& newUrl)
     e.setInformation(i18n("Remove a file called '%1'.", it->text()));
     e.addDocuments(IndexedString(lists), IndexedString(lists));
 
-    bool ret=followUses(e.document(), r, ' '+it->text(), lists, false, newName);
-    if(ret)
+    bool ret=followUses(e.document(), r, ' '+it->text(), lists, false, ' '+newName);
+    if(ret && e.exec())
     {
-        if(e.exec())
+        ret=e.applyAllChanges();
+        
+        if(ret)
         {
-            bool saved=e.applyAllChanges();
-            if(!saved)
-                KMessageBox::error(0, i18n("KDevelop - CMake Support"),
-                                    i18n("Cannot save the change."));
-            else
+            KIO::CopyJob* job=KIO::move(it->url(), newUrl);
+            bool ret=KIO::NetAccess::synchronousRun(job, 0);
+            
+            if(ret)
+            {
                 it->project()->removeFromFileSet(IndexedString(it->url()));
+                it->setUrl(newUrl);
+                it->project()->addToFileSet(IndexedString(it->url()));
+            }
         }
     }
-    else
-    {
-        KMessageBox::error(0, i18n("KDevelop - CMake Support"),
-                              i18n("Cannot remove the file."));
-    }
+
     return ret;
 }
 
 bool CMakeManager::renameFolder(ProjectFolderItem* _it, const KUrl& newUrl)
 {
     CMakeFolderItem* it=static_cast<CMakeFolderItem*>(_it);
-    KUrl lists=it->formerParent()->url();
-    lists.addPath("CMakeLists.txt");
     if(it->type()!=KDevelop::ProjectBaseItem::BuildFolder)
     {
-        it->setText(newUrl.fileName(KUrl::IgnoreTrailingSlash));
-        it->setUrl(newUrl);
-        return true;
+        KIO::CopyJob* job=KIO::move(it->url(), newUrl);
+        bool ret=KIO::NetAccess::synchronousRun(job, 0);
+        if(ret) {
+            it->setUrl(newUrl);
+        }
+        return ret;
     }
+    KUrl lists=it->formerParent()->url();
+    lists.addPath("CMakeLists.txt");
     QString newName=KUrl::relativePath(lists.upUrl().path(), newUrl.path());
     if(newName.startsWith("./"))
         newName.remove(0,2);
@@ -1275,11 +1295,15 @@ bool CMakeManager::renameFolder(ProjectFolderItem* _it, const KUrl& newUrl)
     bool ret=e.exec();
     if(ret)
     {
-        bool saved=e.applyAllChanges();
-        if(!saved)
-            KMessageBox::error(0, i18n("KDevelop - CMake Support"),
-                                  i18n("Could not save the change."));
-        ret=saved;
+        ret=e.applyAllChanges();
+        
+        if(ret) {
+            KIO::CopyJob* job=KIO::move(it->url(), newUrl);
+            ret=KIO::NetAccess::synchronousRun(job, 0);
+            if(ret) {
+                it->setUrl(newUrl);
+            }
+        }
     }
     return ret;
 }
