@@ -259,10 +259,12 @@ int CMakeProjectVisitor::visit(const ProjectAst *project)
     m_projectName = project->projectName();
     if(!m_vars->contains("CMAKE_PROJECT_NAME"))
         m_vars->insert("CMAKE_PROJECT_NAME", QStringList(project->projectName()));
-
+    
     m_vars->insert("PROJECT_NAME", QStringList(project->projectName()));
     m_vars->insert("PROJECT_SOURCE_DIR", QStringList(m_root));
+    m_vars->insert("PROJECT_BINARY_DIR", m_vars->value("CMAKE_CURRENT_BINARY_DIR"));
     m_vars->insert(QString("%1_SOURCE_DIR").arg(m_projectName), QStringList(m_root));
+    m_vars->insert(QString("%1_BINARY_DIR").arg(m_projectName), m_vars->value("CMAKE_CURRENT_BINARY_DIR"));
     return 1;
 }
 
@@ -917,7 +919,14 @@ int CMakeProjectVisitor::visit(const TryCompileAst *tca)
     {
         kDebug(9042) << "project compile" << tca->projectName() << tca->targetName();
     }
-    m_vars->insert(tca->resultName(), QStringList("TRUE"));
+    
+    QString value;
+    if(m_cache->contains(tca->resultName()))
+        value=m_cache->value(tca->resultName()).value;
+    else
+        value="TRUE";
+    
+    m_vars->insert(tca->resultName(), QStringList(value));
     return 1;
 }
 
@@ -1285,7 +1294,8 @@ int CMakeProjectVisitor::visit(const ExecuteProcessAst *exec)
         }
     }
 
-    if(!exec->outputVariable().isEmpty())
+    //FIXME: remove condition when filtering bad output
+    if(!procs.isEmpty() && !exec->outputVariable().isEmpty())
     {
         QByteArray b = procs.last()->readAllStandardOutput();
         QString t;
@@ -1896,6 +1906,25 @@ int CMakeProjectVisitor::visit(const GetPropertyAst* getp)
     return 1;
 }
 
+int CMakeProjectVisitor::visit(const GetDirPropertyAst* getdp)
+{
+    kDebug() << "getprops";
+    QStringList retv;
+    QString dir=getdp->directory();
+    if(dir.isEmpty()) {
+        dir=m_vars->value("CMAKE_CURRENT_SOURCE_DIR").join(QString());
+    } else if(KUrl::isRelativeUrl(dir)) {
+        KUrl u(m_vars->value("CMAKE_CURRENT_SOURCE_DIR").join(QString()));
+        u.addPath(dir);
+        dir=u.path();
+    }
+    
+    retv=m_props[DIRECTORY][dir][getdp->propName()];
+    m_vars->insert(getdp->outputVariable(), retv);
+    
+    return 1;
+}
+
 int CMakeProjectVisitor::visit( const WhileAst * whileast)
 {
     CMakeCondition cond(this);
@@ -2017,6 +2046,7 @@ int CMakeProjectVisitor::walk(const CMakeFileContent & fc, int line, bool isClea
             KSharedPtr<Problem> p(new Problem);
             p->setDescription(i18n("%1 is a deprecated command and should not be used", func.name));
             p->setRange(it->nameRange());
+            p->setFinalLocation(DocumentRange(url.prettyUrl(), KTextEditor::Range(fc.first().range().start.textCursor(), fc.last().range().end.textCursor())));
             m_topctx->addProblem(p);
         }
         element->setContent(fc, line);
@@ -2035,6 +2065,7 @@ int CMakeProjectVisitor::walk(const CMakeFileContent & fc, int line, bool isClea
             KSharedPtr<Problem> p(new Problem);
             p->setDescription(i18n("Unfinished function. "));
             p->setRange(it->nameRange());
+            p->setFinalLocation(DocumentRange(url.prettyUrl(), KTextEditor::Range(fc.first().range().start.textCursor(), fc.last().range().end.textCursor())));
             m_topctx->addProblem(p);
             
             break;
